![](https://github.com/papamarkou/eeyore/workflows/eeyore/badge.svg)

MCMC methods for neural networks.

eeyore can be installed via conda or via pip.

To install eeyore using conda, run
```
conda install -c conda-forge eeyore
```

To install eeyore using pip, run
```
pip install eeyore
```
